@@ -1,7 +1,5 @@
-import re
-
 def split(commands: list[str]) -> dict[str, str]:
-    params = {}
+    params: dict[str, str] = {}
     for elem in commands[2:]:
         if '=' not in elem:
             continue
